api.documents.v1.customer.test_helpers.customer package — Argus-Toolbelt 1.0 documentation

# api.documents.v1.customer.test_helpers.customer package

## Submodules

## api.documents.v1.customer.test_helpers.customer.get_customer_root_folder module

`api.documents.v1.customer.test_helpers.customer.get_customer_root_folder.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/customer/w+, respond with HTTP 403

`api.documents.v1.customer.test_helpers.customer.get_customer_root_folder.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/customer/w+, respond with HTTP 404

`api.documents.v1.customer.test_helpers.customer.get_customer_root_folder.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/customer/w+, respond with HTTP 200

`api.documents.v1.customer.test_helpers.customer.get_customer_root_folder.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/customer/w+, respond with HTTP 401

## Module contents